==> haskell-openssl-streams-1.2.1.3-19-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-openssl-streams.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: openssl-streams
version: 1.2.1.3
id: openssl-streams-1.2.1.3-E54bat3sYhkLwGANB11NCX
key: openssl-streams-1.2.1.3-E54bat3sYhkLwGANB11NCX
license: BSD-3-Clause
maintainer: Gregory Collins <greg@gregorycollins.net>
synopsis: OpenSSL network support for io-streams.
description:
    The openssl-streams library contains io-streams routines for secure
    networking using OpenSSL (by way of HsOpenSSL).
category: Network, IO-Streams
abi: 530bb1e0d683ebc3c33914543a3679ee
exposed: True
exposed-modules:
    System.IO.Streams.SSL
import-dirs: /usr/lib/ghc-8.4.3/site-local/openssl-streams-1.2.1.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/openssl-streams-1.2.1.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/openssl-streams-1.2.1.3
hs-libraries: HSopenssl-streams-1.2.1.3-E54bat3sYhkLwGANB11NCX
depends:
    base-4.11.1.0 bytestring-0.10.8.2
    HsOpenSSL-0.11.4.14-KuFcFAI1s0xHMNxl94hlf3
    io-streams-1.5.0.1-4TKhhvq9gGzC2icTW4sVNs
    network-2.7.0.2-3zQTN3hKcaz6IkeyUSsRrW
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             HsOpenSSL-0.11.4.14-KuFcFAI1s0xHMNxl94hlf3=ba09769728fcce15ea2f7f45ad28781b
             io-streams-1.5.0.1-4TKhhvq9gGzC2icTW4sVNs=a28989bac14c56155d8e2ad7235e055d
             network-2.7.0.2-3zQTN3hKcaz6IkeyUSsRrW=69b658fb7f59eb9acbefe047d83e7e11
haddock-interfaces: /usr/share/doc/haskell-openssl-streams/html/openssl-streams.haddock
haddock-html: /usr/share/doc/haskell-openssl-streams/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-openssl-streams-1.2.1.3-22-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-openssl-streams.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: openssl-streams
version: 1.2.1.3
id: openssl-streams-1.2.1.3-Kb6kPtSoBWKIDkmnyNuUjc
key: openssl-streams-1.2.1.3-Kb6kPtSoBWKIDkmnyNuUjc
license: BSD-3-Clause
maintainer: Gregory Collins <greg@gregorycollins.net>
synopsis: OpenSSL network support for io-streams.
description:
    The openssl-streams library contains io-streams routines for secure
    networking using OpenSSL (by way of HsOpenSSL).
category: Network, IO-Streams
abi: 1f92205b56111a37f3df1e458dd02fe9
exposed: True
exposed-modules:
    System.IO.Streams.SSL
import-dirs: /usr/lib/ghc-8.4.3/site-local/openssl-streams-1.2.1.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/openssl-streams-1.2.1.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/openssl-streams-1.2.1.3
hs-libraries: HSopenssl-streams-1.2.1.3-Kb6kPtSoBWKIDkmnyNuUjc
depends:
    base-4.11.1.0 bytestring-0.10.8.2
    HsOpenSSL-0.11.4.14-JokrEaKNVkkBpDgWnfJIiV
    io-streams-1.5.0.1-1DE7scOOFNtK1PAKVdK58v
    network-2.7.0.2-rh9KFIvQth4GqHFEdJVEv
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             HsOpenSSL-0.11.4.14-JokrEaKNVkkBpDgWnfJIiV=2664a4115c37a6574e9220484511623d
             io-streams-1.5.0.1-1DE7scOOFNtK1PAKVdK58v=4667d18502c9be822da79bad63741975
             network-2.7.0.2-rh9KFIvQth4GqHFEdJVEv=9f4c0094002519cc1dc579d0a3bd3879
haddock-interfaces: /usr/share/doc/haskell-openssl-streams/html/openssl-streams.haddock
haddock-html: /usr/share/doc/haskell-openssl-streams/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
